--[[
    Soundtrack addon for World of Warcraft

    Soundtrack library functions.
    Functions that manage the users list of available music tracks.
]]

-- Remove track popup
StaticPopupDialogs["SOUNDTRACK_REMOVETRACK"] = {
    text = [[Do you want to remove this track from your library?]],
    button1 = "OK",
    button2 = "Cancel",
    OnAccept = function() 
        Soundtrack.Library.RemoveTrack(SoundtrackFrame_SelectedTrack) 
    end,
    timeout = 0,
    whileDead = 1,
    hideOnEscape = 1
}


Soundtrack.Library.CurrentlyPlayingTrack = nil


function Soundtrack.Library.AddTrack(trackName, _length, _title, _artist, _album)
    Soundtrack_Tracks[trackName] = { length = _length, title = _title, artist = _artist, album = _album }
    Soundtrack.SortTracks()
end

    
function Soundtrack.Library.AddDefaultTrack(trackName, _length, _title, _artist, _album)             
    Soundtrack_Tracks[trackName] = { length = _length, title = _title, artist = _artist, album = _album, defaultTrack = true }
    Soundtrack.SortTracks()
end


function Soundtrack.Library.PauseMusic()
    --StopMusic()
    Soundtrack.Library.CurrentlyPlayingTrack = "None"
    Soundtrack.TraceLibrary("Playing empty track.")
    Soundtrack.TraceLibrary("PlayMusic('Interface\\AddOns\\Soundtrack\\EmptyTrack.mp3')")
    PlayMusic("Interface\\AddOns\\Soundtrack\\EmptyTrack.mp3")
    SoundtrackFrame_TouchTracks()
end

function Soundtrack.Library.StopTrack()
    Soundtrack.TraceLibrary("StopTrack()")
    Soundtrack.Library.CurrentlyPlayingTrack = nil
    Soundtrack.TraceLibrary("StopMusic")
    StopMusic()
    SoundtrackFrame_TouchTracks()
end    
    
function Soundtrack.Library.PlayTrack(trackName, soundEffect)

    if soundEffect == nil then soundEffect = false end

    Soundtrack.TraceLibrary("PlayTrack(".. Soundtrack.GetPathFileName(trackName) ..")")
    
    -- Check if the track is valid
    if not Soundtrack_Tracks[trackName] then
        return
    end
    
    -- Check if that track is already playing
    if trackName == Soundtrack.Library.CurrentlyPlayingTrack then
        return
    end
    
    local trackInfo = Soundtrack_Tracks[trackName]
    
    -- TODO : Change DefaultScore name
    local fileName
    if trackInfo.defaultTrack then
        fileName = "Sound\\Music\\" .. trackName .. ".mp3"
    else
        fileName = "Interface\\AddOns\\Soundtrack\\Music\\"..trackName..".mp3"
    end        
    
    -- Everything ok, play the track
    if not soundEffect then
        Soundtrack.Library.CurrentlyPlayingTrack = trackName
        SetNowPlayingText(trackInfo.title, trackInfo.artist, trackInfo.album)
        Soundtrack.TraceLibrary("PlayMusic(".. fileName ..")")
        -- Soundtrack.Library.StopTrack()
        PlayMusic(fileName)
    else
        Soundtrack.TraceLibrary("PlaySoundFile(".. fileName ..")")
        PlaySoundFile(fileName) -- sound effect. play the music overlapping other music
    end
    
    -- Update the UI if its opened
    SoundtrackFrame_TouchTracks()
end

    
-- Removes a track from the library.
function Soundtrack.Library.RemoveTrackWithConfirmation()        
    -- Confirmation
    StaticPopup_Show("SOUNDTRACK_REMOVETRACK")
end
    
function Soundtrack.Library.RemoveTrack(trackName)
    if trackName then
        Soundtrack_Tracks[trackName] = nil
        Soundtrack.SortTracks()
        
        -- Remove the track from any event that assigns it
        for _,eventTab in ipairs(Soundtrack_EventTabs) do
            for k,v in Soundtrack_Events[eventTab] do 
                for i,tn in ipairs(v.tracks) do
                    if tn == trackName then
                        Soundtrack.TraceLibrary("Removed assigned track "..trackName)
                        table.remove(v.tracks, i)
                        break
                    end
                end
            end
        end
        
        -- Refresh assigned counts
        SoundtrackFrame_RefreshEvents()
    end
end